==> sl7_fwork_flutter-0.0.10.tar.gz: lib/http/http_utils.dart <==
import 'dart:convert';

import 'package:sl7_fwork_flutter/http/models.dart';
import 'package:http/http.dart' as http;

class HttpUtils {
  static String getErrorMsgFromApi(
    Map<String, dynamic> error,
  ) {
    return error['ExceptionMessage'] ?? error['data'] ?? error['message'];
  }

  static Future<ApiResult> httpSafeExecute({
    required Future<http.Response> Function() func,
    dynamic Function(dynamic data)? onOverrideData,
    dynamic Function(dynamic data)? onSuccess,
    String? responseDataPropPath,
  }) async {
    ApiResult result;

    try {
      final response = await func();

      if (response.statusCode == 200) {
        Map<String, dynamic> responsebody = jsonDecode(response.body);

        var data = responseDataPropPath != null ? responsebody[responseDataPropPath] : responsebody;
        if (onOverrideData != null) {
          data = onOverrideData(data);
        }

        result = ApiResult(
          success: true,
          data: data,
          message: 'Operação realizada com sucesso.',
        );

        if (onSuccess != null) {
          onSuccess(data);
        }
      } else {
        Map<String, dynamic> error = jsonDecode(response.body);

        result = ApiResult(
          success: false,
          message:
              'Erro na operação. ${HttpUtils.getErrorMsgFromApi(error)}',
        );
      }
    } catch (error) {
      result = ApiResult(
        success: false,
        message: 'Erro na operação. ${error.toString()}',
      );
    }

    return result;
  }
}

==> sl7_fwork_flutter-0.0.17.tar.gz: lib/http/http_utils.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:sl7_fwork_flutter/http/models.dart';
import 'package:http/http.dart' as http;

class HttpUtils {
  static String getErrorMsgFromApi(
    Map<String, dynamic> error,
  ) {
    return error['exceptionMessage'] ?? error['ExceptionMessage'] ?? error['data'] ?? error['Data'] ?? error['message'] ?? error['Message'];
  }

  static Future<ApiResult> safeExecute({
    required Future<http.Response> Function() func,
    dynamic Function(dynamic data)? onOverrideData,
    dynamic Function(dynamic data)? onSuccess,
    String? responseDataPropPath,
  }) async {
    ApiResult result;

    try {
      final response = await func();

      if (response.statusCode == 200) {
        var responsebody = jsonDecode(response.body);

        var data = responseDataPropPath != null && responsebody is Map<String, dynamic> ? responsebody[responseDataPropPath] : responsebody;
        if (onOverrideData != null) {
          data = onOverrideData(data);
        }

        result = ApiResult(
          success: true,
          data: data,
          message: 'Operação realizada com sucesso.',
        );

        if (onSuccess != null) {
          onSuccess(data);
        }
      } else {
        Map<String, dynamic> error = jsonDecode(response.body);

        result = ApiResult(
          success: false,
          message:
              'Erro na operação. ${HttpUtils.getErrorMsgFromApi(error)}',
        );
      }
    } catch (error) {
      result = ApiResult(
        success: false,
        message: 'Erro na operação. ${error.toString()}',
      );
    }

    return result;
  }
}
